Package directory for bilayer tight binding model

Directory structure
  * bilayer_letb/ - Main code package
  * workflow/ - Workflow files for generating data/
  * data/ - Dataset for fitting
  * fit/ -  Fitting methods for parameters using data/
  * examples/ - Simple examples using our model to generate band structures

Install and import model
```python
pip install bilayer_letb
from bilayer_letb.api import tb_model
```

Full code repository: https://github.com/qmc-hamm/bilayer_tight_binding
